==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/AnnotationCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Annotation;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class AnnotationCollectionRequest extends CollectionPageEntityRequest<Annotation, AnnotationRequest>{

    protected ContextPath contextPath;

    public AnnotationCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Annotation.class, cp -> new AnnotationRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public BulkdeletefailureCollectionRequest annotation_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("Annotation_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest annotation_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("Annotation_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest annotation_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("Annotation_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest annotation_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("Annotation_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest annotation_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("Annotation_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest annotation_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("Annotation_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest annotation_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("Annotation_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest annotation_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("Annotation_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/AnnotationCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Annotation;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class AnnotationCollectionRequest extends CollectionPageEntityRequest<Annotation, AnnotationRequest>{

    protected ContextPath contextPath;

    public AnnotationCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Annotation.class, cp -> new AnnotationRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public BulkdeletefailureCollectionRequest annotation_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("Annotation_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest annotation_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("Annotation_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest annotation_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("Annotation_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest annotation_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("Annotation_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest annotation_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("Annotation_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest annotation_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("Annotation_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest annotation_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("Annotation_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest annotation_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("Annotation_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

}
